.. _Coding conventions:

Coding conventions
===========================

The |PyInstaller| project follows the :pep:`8` Style Guide for Python Code for
new code.

.. TODO: precise how to use flake8

Please check your code with a style guide checker, e.g. flake8.

Please abstain from reformatting existing code, even it it doesn't follow
PEP 8. We will not accept reformatting changes since they make it harder to
review the changes and to follow changes in the long run. For a complete
rational please see :issue:`2727`.

.. include:: ../_common_definitions.txt

.. Emacs config:
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
